dabcd_min_var: Allocation Probabilities Using Doubly Adaptive Biased Coin Design with Minimal Variance Strategy for Binary Endpoint
Description
dabcd_min_var can be used for doubly adaptive biased coin design with minimal variance
strategy for binary outcomes, targeting generalized Neyman allocation and generalized RSIHR allocation. The return
of this function is a vector of allocation probabilities to each arm, with the pre-specified number of participants in the trial.
a vector representing the number of participants with success results for each arm
estimated from the current data .
Ntotal1
a vector representing the total number of participants for each arm
estimated from the current data.
armn
number of total arms in the trial.
type
allocation type, with choices from 'RSIHR' and 'Neyman'.
dabcd
an indicator of whether to apply Hu & Zhang's formula (Hu2004RARtrials), with choices from FALSE and TRUE.
TRUE represents allocation probabilities calculated using Hu & Zhang's formula;
FALSE represents allocation probabilities calculated before applying Hu & Zhang's formula.
Default value is set to FALSE.
gamma
tuning parameter in Hu & Zhang's formula (Hu2004RARtrials). When dabcd=FALSE, this parameter does not need
to be specified. Default value is set to 2.
Author
Chuyao Xu, Thomas Lumley, Alain Vandal
Details
The function simulates allocation probabilities for doubly adaptive biased coin design with minimal variance strategy targeting
generalized Neyman allocation and generalized RSIHR allocation with 2-5 arms. The output of this function is based on Hu \& Zhang's formula Hu2004RARtrials.
With more than two armd the one-sided nominal level of each test is alphaa divided by arm*(arm-1)/2; a Bonferroni correction.