#The forward-looking Gittins Index rule with delayed responses follow a normal distribution
#with a mean of 30 days and a standard deviation of 3 days
# \donttest{
sim_flgi_known_var(Gittinstype='KV',df=0.995,Pats=10,nMax=50000,
TimeToOutcome=expression(rnorm( length( vStartTime ),30, 3)),enrollrate=0.5,
K=3,noRuns2=100,Tsize=852,block=20,rule='FLGI PM',prior_n=rep(1,3),
prior_mean=rep(9/100,3),stopbound=(-2.1725),mean=c(9.1/100,8.83/100,8.83/100),
sd=c(0.009,0.009,0.009),side='lower')# }
#The controlled forward-looking Gittins Index rule with delayed responses follow a
#normal distribution with a mean of 30 days and a standard deviation of 3 days
# \donttest{
sim_flgi_known_var(Gittinstype='KV',df=0.995,Pats=10,nMax=50000,
TimeToOutcome=expression(rnorm( length( vStartTime ),30, 3)),enrollrate=0.1,
K=3,noRuns2=100,Tsize=852,block=20,rule='CFLGI',prior_n=rep(1,3),
prior_mean=rep(9/100,3),stopbound=(-2.075),mean=c(9.1/100,8.83/100,8.83/100),
sd=c(0.009,0.009,0.009),side='lower')# }
Run the code above in your browser using DataLab